/**
 * Database Management API
 * Use the Database Management API to perform tasks such as obtaining performance and resource usage metrics
for a fleet of Managed Databases or a specific Managed Database, creating Managed Database Groups, and
running a SQL job on a Managed Database or Managed Database Group.

 * OpenAPI spec version: 20201101
 *
 *
 * NOTE: This class is auto generated by OracleSDKGenerator.
 * Do not edit the class manually.
 *
 * Copyright (c) 2020, 2023, Oracle and/or its affiliates.  All rights reserved.
 * This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.
 */
import * as model from "../model";
/**
 * The details of an external DB system.
 */
export interface ExternalDbSystem {
    /**
     * The [OCID](https://docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm) of the external DB system.
     */
    "id": string;
    /**
     * The user-friendly name for the DB system. The name does not have to be unique.
     */
    "displayName": string;
    /**
     * The [OCID](https://docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm) of the compartment.
     */
    "compartmentId": string;
    /**
     * The [OCID](https://docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm) of the DB system discovery.
     */
    "dbSystemDiscoveryId"?: string;
    /**
     * The [OCID](https://docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm) of the management agent used during the discovery of the DB system.
     */
    "discoveryAgentId"?: string;
    /**
     * Indicates whether the DB system is a cluster DB system or not.
     */
    "isCluster"?: boolean;
    /**
     * The Oracle Grid home directory in case of cluster-based DB system and
     * Oracle home directory in case of single instance-based DB system.
     *
     */
    "homeDirectory"?: string;
    "databaseManagementConfig"?: model.ExternalDbSystemDatabaseManagementConfigDetails;
    "stackMonitoringConfig"?: model.ExternalDbSystemStackMonitoringConfigDetails;
    /**
     * The current lifecycle state of the external DB system resource.
     */
    "lifecycleState": ExternalDbSystem.LifecycleState;
    /**
     * Additional information about the current lifecycle state.
     */
    "lifecycleDetails"?: string;
    /**
     * The date and time the external DB system was created.
     */
    "timeCreated": Date;
    /**
     * The date and time the external DB system was last updated.
     */
    "timeUpdated": Date;
}
export declare namespace ExternalDbSystem {
    enum LifecycleState {
        Creating = "CREATING",
        Active = "ACTIVE",
        Updating = "UPDATING",
        Deleting = "DELETING",
        Deleted = "DELETED",
        Inactive = "INACTIVE",
        /**
         * This value is used if a service returns a value for this enum that is not recognized by this
         * version of the SDK.
         */
        UnknownValue = "UNKNOWN_VALUE"
    }
    function getJsonObj(obj: ExternalDbSystem): object;
    function getDeserializedJsonObj(obj: ExternalDbSystem): object;
}
